/*
    Text maid
    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __GENERAL_H__
#define __GENERAL_H__


#include "tmaid.h"


/*	åȤ
	   ptw,TXTɥ
	cursor,												*/
void draw_caret(TEXTWND *ptw,GdkPoint *cursor);


/*	˥塼ꤹ
	ptw,TXTɥ													*/
void set_menu_bar(TEXTWND *ptw);


/*	ϰϤ褹
	ptw,TXTɥ
	start,
	  end,λ																*/
void clear_sel(TEXTWND *ptw,GdkPoint *start,GdkPoint *end);


/*	ư
	ptw,TXTɥ
	top,Ťκɸ														*/
void move_text_window(TEXTWND *ptw,GdkPoint *top);


/*	åȰ֤˥ǡ/񤭤
	   ptw,TXTɥ
	  text,ǡǼݥ
	length,ǡΥХȿ
	 caret,TRUE:ư,FALSE:ưʤ
	select,TRUE:򤹤,FALSE:򤷤ʤ
	   RET,դԤDOING¤,NULL:顼							*/
DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
											gboolean caret,gboolean select);


/*	ޡޤ֤
	ptw,TXTɥ													*/
void modify_margin(TEXTWND *ptw);


/*	ե¸䤤碌
	ptw,TXTɥ
	RET,TRUE:եĤ,FALSE:եĤʤ						*/
gboolean prompt_close(TEXTWND *ptw);


/*	ꥹȤ
	  d,ꥹȤƬ
	RET,ꥹȤο													*/
gint delete_list(DOING **d);


/*	Խ
	 ptw,TXTɥ
	kind,TRUE:redo,FALSE:undo												*/
void history_operation(TEXTWND *ptw,gboolean kind);


/*	ޡǲԤ
	 ptw,TXTɥ													*/
void margin_operation(TEXTWND *ptw);


/*	֤򥹥ڡѴ
	 ptw,TXTɥ													*/
void tab_operation(TEXTWND *ptw);


/*	Ԥذư
	 ptw,TXTɥ
	line,(1...)														*/
void jump_operation(TEXTWND *ptw,gint line);


#endif
